Include "param.pro"
Include "Fe1010.pro"

NL_NbrMaxIter = 20;   // Max nbr iterations for iteractive loop
NL_Eps        = 1.e-6; // Convergence criterium for iteractive loop
NL_Relax      = 1;   // Relaxation Factor for iteractive loop

Group {
    Air          = Region[AIR];
    Core         = Region[CORE];
    LeftCore     = Region[LEFT_CORE];
    Ind          = Region[INDUCTOR];

    OuterSurface    = Region[SKIN_AIR];
    CoreSurface     = Region[SKIN_CORE];
    LeftCoreSurface = Region[SKIN_LEFTCORE];
    
    DomainS_Mag = Region[{Ind}];
    Domain_Mag  = Region[{Core, LeftCore, Air, Ind}];
    
    Domain_Fe1010 = Region[{Core, LeftCore}];
    Domain_NonFe  = Region[{Air, Ind}];
}

Function {
    mu0 = 4.e-7 * Pi;  
    murCore = 2000.;
    
    nu [ Domain_NonFe ]      = 1. / mu0;
    
 //   nu [ Region[{Core, LeftCore}]] = 1. / (murCore*mu0);

    //nonlinear material for picard scheme
    nu [ Domain_Fe1010 ] = InterpolationLinear[Norm[$1]]{List[nu_Fe1010_couples]};
    //nu [ Domain_Fe1010 ] = (Norm[$1] > 19.0) ? 1./mu0 : 1. / InterpolationLinear[Norm[$1]]{List[nu_Fe1010_couples]};

    
    //Solenoid current
    Sc          = (Inductor_Dx-Inductor_dx)*Inductor_Lyz;  //cross section of coil
    Ns          = 2000.;          //Number of turns of the inductor Ind
    Val_Current = 1.;           //current in the inductor

    //calculation of current vectors
    xc = Inductor_cx;
    zc = Inductor_cz;
    
    js[ Ind ] = Ns/Sc * Val_Current *
                Vector[-Sin[Atan2[Z[]-zc,X[]-xc]],
                        0,
                        Cos[Atan2[Z[]-zc,X[]-xc]]] ;

    //only for displaying the vectors:
    js[ Core] = Vector[0,0,0];
}

Constraint {
    { Name MagneticVectorPotential_3D; Type Assign;
        Case {
            { Region OuterSurface ; Value 0.; }
        }
    }
    
    { Name Gauge; Type Assign;
        Case {
          { Region Domain_Mag; SubRegion #{OuterSurface,CoreSurface,LeftCoreSurface}; Value 0.0; }
        }
    }

}

Jacobian {
    { Name Vol ;
        Case { 
                { Region All ; Jacobian Vol ; }
        }
    }
}

Integration {
    { Name CurlCurl ;
        Case { {Type Gauss ;
            Case {  
                    { GeoElement Triangle ; NumberOfPoints 4 ; }
                    { GeoElement Tetrahedron ; NumberOfPoints 4 ; }
                 }
            }
        }
    }
}

Include "Magsta_a_3D_nl.pro"

PostOperation {
    { 
        Name a_b_j; NameOfPostProcessing MagSta_a_3D_nl;
        Operation {
//            Print[ a, OnElementsOf Domain_Mag, File "CoreSta_a_p.pos" ];
            Print[ b, OnElementsOf Domain_Mag, File "CoreSta_b_p.pos" ];
            Print[ j, OnElementsOf #{Ind, Core},  //OnElementsOf DomainS_Mag, 
                      File "CoreSta_j.pos" ];
        }
    }
 
}

